import React, { useState, useEffect } from "react";
import './index.css';
import axios from "axios";
import moment from "moment";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faBell, faBars, faSearch, faUsers, faCog, faHandHoldingHeart, faTachometerAlt, faSignOutAlt, faCheckCircle, faTimesCircle, faComment, faComments, faSlidersH, faHouseDamage, faEdit, faTrashAlt } from "@fortawesome/free-solid-svg-icons";
import image from "../../Assests/Images/logo.jpeg";
import image2 from "../../Assests/Images/man.png";
import { Link } from "react-router-dom";
import { Sidenav } from "../../Components/Sidenav";

export const UserList = () => {
    const [isSidebarCollapsed, setIsSidebarCollapsed] = useState(false);
    const [user, setUser] = useState(null);
    const [users, setUsers] = useState([]);

    React.useEffect(() => {
        const callApi = async () => {

            const response = await axios.get("http://localhost:8000/api/users");
            if (response?.data?.success) {
                setUsers(response?.data?.data);
            }
        };
        callApi();
    }, []);

    const toggleSidebar = () => {
        setIsSidebarCollapsed(!isSidebarCollapsed);
    };


    useEffect(() => {
        const storedUser = JSON.parse(localStorage.getItem("user"));
        if (storedUser) {
            setUser(storedUser);
        }
    }, []);


    return (
        <div className="admin">
            {/* Header */}
            <div className="admin-header">
                <div className="admin-header-img-bx">
                    <img src={image} alt="Logo" />
                    <h1 >RippleAid</h1>
                    <span onClick={toggleSidebar} className="menu-icon">
                        <FontAwesomeIcon icon={faBars} />
                    </span>
                </div>

                <div className="admin-header-serch-bx">
                    <form action="">
                        <input type="text" placeholder="Search" />
                        <button><FontAwesomeIcon icon={faSearch} /></button>
                    </form>
                </div>

                <div className="admin-header-user-bx">
                    <div className="admin-header-icon">
                        <span><FontAwesomeIcon icon={faBell} /></span>
                    </div>
                    {user ? (
                        <img src={user.image ? `http://localhost:8000/${user.image}` : "/default-avatar.png"} alt="User" />
                    ) : (
                        <img src={image2} alt="User" />
                    )}

                    <form action=""
                        onSubmit={async (e) => {
                            e.preventDefault();
                            try {
                                const token = localStorage.getItem("token");
                                const response = await axios.post(
                                    "http://localhost:8000/api/logout",
                                    {},
                                    {
                                        headers: {
                                            Authorization: `Bearer ${token}`, // Token পাঠানো হচ্ছে
                                        },
                                    }
                                );

                                if (response?.data?.message === "Successfully logged out") {
                                    localStorage.removeItem("token");
                                    localStorage.removeItem("user"); // User data ও রিমুভ করা হচ্ছে
                                    window.location.href = "/login"; // Redirect
                                }
                            } catch (error) {
                                console.error("Error logging out:", error);
                            }
                        }}
                    >
                        <button><FontAwesomeIcon icon={faSignOutAlt} /></button>
                    </form>
                </div>
            </div>

            {/* Sidebar & Main Content */}
            <div className="admin-content">
                <Sidenav />

                {/* Main Content */}
                <div className="admin-content-main">
                    <div className="aid-control">
                        <h1>Users </h1>
                        <table>
                            <thead>
                                <tr>
                                    <th>SL NO</th>
                                    <th>Name</th>
                                    <th>Email</th>
                                    <th>Phone no</th>
                                    <th>Image</th>
                                    <th>Role</th>
                                    <th>Action</th>
                                </tr>
                            </thead>
                            <tbody>
                                {users.map((user, index) => (
                                    <tr key={user._id}>
                                        <td>{index + 1}</td>
                                        <td>{user.name}</td>
                                        <td>{user.email}</td>
                                        <td>{user.phone}</td>
                                        <td><img src={user.image ? `http://localhost:8000/${user.image}` : "/default-avatar.png"} alt="User" style={{ width: "100px", height: "100px" }} /></td>
                                        <td>{user.active_role?.name}</td>
                                        <td >
                                            <Link to={`/be/user-edit/${user.id}`} style={{ background: "white", color: "black", width: "50px", height: "50px", padding: "15px", borderRadius: "50%", marginRight: "8px" }}><FontAwesomeIcon icon={faEdit} /></Link>
                                        </td>
                                    </tr>
                                ))}

                            </tbody>
                        </table>

                    </div>
                </div>
            </div>

            {/* Footer */}
            <div className="admin-footer">
                <p>2021 RippleAid &copy; Copyright</p>
            </div>
        </div>
    );
};
